@@ -7,6 +7,7 @@ import os
 from . import px_file
 from . import px_process
 from . import px_ipc_map
+from . import px_cwdfriends
 from . import px_loginhistory
 
 
@@ -170,6 +171,30 @@ def to_ipc_lines(ipc_map):
     return return_me
 
 
+def print_cwd_friends(process, all_processes, all_files):
+    friends = px_cwdfriends.PxCwdFriends(process, all_processes, all_files)
+
+    print("Others sharing this process' working directory (" +
+          (friends.cwd or "<UNKNOWN>") +
+          ")")
+    if not friends.cwd:
+        print('  Working directory unknown, try again or try "sudo px ' +
+              str(process.pid) +
+              '"')
+        return
+
+    if friends.cwd == '/':
+        print("  Working directory too common, never mind.")
+        return
+
+    if len(friends.friends) == 0:
+        print("  Nobody else shares this working directory.")
+        return
+
+    for friend in friends.friends:
+        print("  " + str(friend))
+
+
 def print_fds(process, processes):
     # type: (px_process.PxProcess, Iterable[px_process.PxProcess]) -> None
 
@@ -177,9 +202,15 @@ def print_fds(process, processes):
     print(datetime.datetime.now().isoformat() +
           ": Now invoking lsof, this can take over a minute on a big system...")
 
-    files = px_file.get_all(process.pid, px_ipc_map.FILE_TYPES)
-    print(datetime.datetime.now().isoformat() +
-          ": lsof done, proceeding.")
+    # Flush what we have so far so the user has something to read during the pause.
+    # This is useful when piping output into a pager like moar or less.
+    sys.stdout.flush()
+
+    files = px_file.get_all()
+    print(datetime.datetime.now().isoformat() + ": lsof done, proceeding.")
+
+    print("")
+    print_cwd_friends(process, processes, files)
 
     is_root = (os.geteuid() == 0)
     ipc_map = px_ipc_map.IpcMap(process, files, processes, is_root=is_root)
@@ -231,7 +262,7 @@ def print_start_time(process):
         ))
 
 
-def print_process_info(pid):
+def print_pid_info(pid):
     # type: (int) -> None
     processes = px_process.get_all()
 
@@ -240,6 +271,11 @@ def print_process_info(pid):
         sys.stderr.write("No such PID: {}\n".format(pid))
         exit(1)
 
+    print_process_info(process, processes)
+
+
+def print_process_info(process, processes):
+    # type: (px_process.PxProcess, List[px_process.PxProcess]) -> None
     print_command_line(process)
 
     # Print a process tree with all PID's parents and all its children
