@@ -14,7 +14,7 @@ def test_lsof_to_files():
     lsof += '\0'.join(["f7", "au", "tREG", "n/someotherfile", "\n"])
     lsof += '\0'.join(["f7", "a ", "n(revoked)", "\n"])
 
-    files = px_file.lsof_to_files(lsof, None, None)
+    files = px_file.lsof_to_files(lsof)
 
     assert len(files) == 5
 
@@ -60,15 +60,21 @@ def test_lsof_to_files():
 
 
 def test_get_all():
-    files = px_file.get_all(None)
+    files = px_file.get_all()
 
     # As non-root I get 6000 on my system, 100 should be fine anywhere. And if
     # not, we'll just have to document our finding and lower this value
     assert len(files) > 100
 
+    cwd_count = 0
+    for file in files:
+        if file.fdtype == 'cwd':
+            cwd_count += 1
+    assert cwd_count > 0
+
 
 def lsof_to_file(shard_array):
-    return px_file.lsof_to_files('\0'.join(shard_array + ["\n"]), None, None)[0]
+    return px_file.lsof_to_files('\0'.join(shard_array + ["\n"]))[0]
 
 
 def test_listen_name():
@@ -142,7 +148,10 @@ def test_str_resolve():
     test_me = px_file.PxFile()
     test_me.type = "IPv4"
     test_me.name = "127.0.0.1:51786->8.8.8.8:https"
-    assert str(test_me) == "[IPv4] localhost:51786->google-public-dns-a.google.com:https"
+    assert str(test_me) in [
+        "[IPv4] localhost:51786->google-public-dns-a.google.com:https",
+        "[IPv4] localhost:51786->dns.google:https",
+    ]
 
     test_me = px_file.PxFile()
     test_me.type = "IPv4"
